# How to Contribute
Simply, create 
[an issue with ECU addressing data](https://github.com/mdabrowski1990/uds-address/issues/new?template=01_add_ecu.md)
or [contact us](https://github.com/mdabrowski1990/uds-address?tab=readme-ov-file#contact) (preferably via discord).  

**We are unable to check the provided data in the vehicles (obviously, we do not have access to all of them), 
but we hope that all of you cooperate and provide all the data we ask for, so we can be sure about its correctness.**